==> podwiki-0.8.5.tgz: podwiki-0.8.5/support/edit-dot-pod.pl <==
#!/usr/bin/perl

 #
 #   $Id: edit-dot-pod.pl,v 1.1 2007/01/18 19:17:44 zarahg Exp $
 #
 #   This  file  is  part of the  PodWiki  web-based authoring tool.
 #
 #   By  accessing  this software,  PodWiki,  you are  duly informed
 #   of and  agree to be  bound  by the  conditions  described below
 #   in this notice:
 #
 #   This software product, PodWiki,  is developed by  Thomas Linden
 #   and   copyrighted  (C) 2003-2005   by  Thomas Linden,  with all
 #   rights reserved.
 #
 #   There is  no charge for  PodWiki software. You can redistribute
 #   it and/or modify it under  the terms of the  GNU General Public
 #   License, which is incorporated by reference herein.
 #
 #   PodWiki is distributed WITHOUT ANY WARRANTY,IMPLIED OR EXPRESS,
 #   OF  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that
 #   the  use of it will not infringe on any third party's intellec-
 #   tual property rights.
 #
 #   You  should  have  received a  copy  of  the GNU General Public
 #   License along with PodWiki.  Copies  can also be obtained from:
 #
 #     http://www.gnu.org/copyleft/gpl.html
 #
 #   or by writing to:
 #
 #     Free Software Foundation, Inc.
 #     59 Temple Place, Suite 330
 #     Boston, MA 02111-1307
 #     USA
 #
 #   Or contact:
 #
 #    "Thomas Linden" <tom@daemon.de>
 #
 #   Additional Copyrights:
 #
 #


use Storable qw(lock_store lock_retrieve);
use Data::Dumper;
use Digest::MD5 qw(md5_hex);

my($file) = @ARGV;

if (! $file) {
  print STDERR "Edit a .pod* podwiki data storage file.\n";
  print STDERR "Usage: $0 <file>\n";
  exit;
}

if (-e $file) {
    my $ref = lock_retrieve($file);
    my $orig = Dumper($ref);
    $orig =~ s/^\$VAR1/\$ref/;
    my $editfile = "/tmp/.pod.$$";
    open T, ">$editfile" or die "Could not create $editfile: $!\n";
    print T $orig;
    close T;
    my $origmd5 = md5_hex($orig);
    system("vi $editfile") and die "Could not edit $editfile: $!\n";
    open T, "<$editfile" or die "Could not open $editfile: $!\n";
    my $new = join "", <T>;
    close T;
    my $newmd5 = md5_hex($new);
    if ($newmd5 eq $origmd5) {
       print "Content unchanged - abort\n";
    }
    else {
       eval $new;
       lock_store($ref, $file) or die "Can't store struct to $file: $!\n";
    }
}
else {
  print "File $file does not exist yet, ignoring.\n";
}

==> podwiki-0.9.0.tgz: podwiki-0.9.0/support/edit-dot-pod.pl <==
#!/usr/bin/perl

 #
 #   $Id: edit-dot-pod.pl,v 1.2 2007/01/31 16:17:21 zarahg Exp $
 #
 #   This  file  is  part of the  PodWiki  web-based authoring tool.
 #
 #   By  accessing  this software,  PodWiki,  you are  duly informed
 #   of and  agree to be  bound  by the  conditions  described below
 #   in this notice:
 #
 #   This software product, PodWiki,  is developed by  Thomas Linden
 #   and   copyrighted  (C) 2003-2005   by  Thomas Linden,  with all
 #   rights reserved.
 #
 #   There is  no charge for  PodWiki software. You can redistribute
 #   it and/or modify it under  the terms of the  GNU General Public
 #   License, which is incorporated by reference herein.
 #
 #   PodWiki is distributed WITHOUT ANY WARRANTY,IMPLIED OR EXPRESS,
 #   OF  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that
 #   the  use of it will not infringe on any third party's intellec-
 #   tual property rights.
 #
 #   You  should  have  received a  copy  of  the GNU General Public
 #   License along with PodWiki.  Copies  can also be obtained from:
 #
 #     http://www.gnu.org/copyleft/gpl.html
 #
 #   or by writing to:
 #
 #     Free Software Foundation, Inc.
 #     59 Temple Place, Suite 330
 #     Boston, MA 02111-1307
 #     USA
 #
 #   Or contact:
 #
 #    "Thomas Linden" <tom@daemon.de>
 #
 #   Additional Copyrights:
 #
 #


use Storable qw(lock_store lock_retrieve);
use Data::Dumper;
use Digest::MD5 qw(md5_hex);

my($file) = @ARGV;

if (! $file) {
  print STDERR "Edit a .pod* podwiki data storage file.\n";
  print STDERR "Usage: $0 <file>\n";
  exit;
}

if (-e $file) {
    my $VAR1 = lock_retrieve($file);
    my $orig = Dumper($VAR1);
    my $editfile = "/tmp/.pod.$$";
    open T, ">$editfile" or die "Could not create $editfile: $!\n";
    print T $orig;
    close T;
    my $origmd5 = md5_hex($orig);
    system("vi $editfile") and die "Could not edit $editfile: $!\n";
    open T, "<$editfile" or die "Could not open $editfile: $!\n";
    my $new = join "", <T>;
    close T;
    my $newmd5 = md5_hex($new);
    if ($newmd5 eq $origmd5) {
       print "Content unchanged - abort\n";
    }
    else {
       eval $new;
       lock_store($VAR1, $file) or die "Can't store struct to $file: $!\n";
    }
}
else {
  print "File $file does not exist yet, ignoring.\n";
}
